]> git.sesse.net Git - stockfish/blobdiff - src/tt.h
Increase TT size limit to 8 GB
[stockfish] / src / tt.h
index 0b7ccbe8f948ecacc603b3d189c387c16d6b2008..2b2ce606eff1bd8615f7834101d70f7c8c550641 100644 (file)
--- a/src/tt.h
+++ b/src/tt.h
@@ -72,7 +72,21 @@ private:
   int16_t depth_;
 };
 
-/// The transposition table class.  This is basically just a huge array
+
+/// This is the number of TTEntry slots for each position
+const int ClusterSize = 5;
+
+/// Each group of ClusterSize number of TTEntry form a TTCluster
+/// that is indexed by a single position key. Cluster is padded
+/// to a cache line size so to guarantee always aligned accesses.
+
+struct TTCluster {
+  TTEntry data[ClusterSize];
+  char cache_line_padding[64 - sizeof(TTEntry[ClusterSize])];
+};
+
+
+/// The transposition table class. This is basically just a huge array
 /// containing TTEntry objects, and a few methods for writing new entries
 /// and reading new ones.
 
@@ -81,27 +95,27 @@ class TranspositionTable {
 public:
   TranspositionTable();
   ~TranspositionTable();
-  void set_size(unsigned mbSize);
+  void set_size(size_t mbSize);
   void clear();
   void store(const Key posKey, Value v, ValueType type, Depth d, Move m);
   TTEntry* retrieve(const Key posKey) const;
   void prefetch(const Key posKey) const;
   void new_search();
   void insert_pv(const Position& pos, Move pv[]);
-  void extract_pv(const Position& pos, Move pv[]);
+  void extract_pv(const Position& pos, Move pv[], const int PLY_MAX);
   int full() const;
 
 private:
   inline TTEntry* first_entry(const Key posKey) const;
 
// Be sure 'writes' is at least one cacheline away
   // from read only variables.
   unsigned char pad_before[64 - sizeof(unsigned)];
   unsigned writes; // heavy SMP read/write access here
   unsigned char pad_after[64];
 
-  unsigned size;
-  TTEntry* entries;
+  size_t size;
+  TTCluster* entries;
   uint8_t generation;
 };
@@ -81,27 +95,27 @@ class TranspositionTable {
   inline TTEntry* first_entry(const Key posKey) const;
 
-  // Be sure 'writes' is at least one cacheline away
+  // Be sure 'writes' is at least one cache line away
   // from read only variables.
   unsigned char pad_before[64 - sizeof(unsigned)];